@@ -14,4 +14,4 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-kdb_modules_dir = "/2021Q3/lib/krb5/plugins/kdb"
+kdb_modules_dir = "/usr/pkg/lib/krb5/plugins/kdb"
