@@ -5,9 +5,9 @@
 # This is a deluser script for NetBSD systems whose userdel(8) doesn't
 # accept "$" in the username.
 
-awkprog="/usr/bin/gawk"
+awkprog="/usr/bin/awk"
 mktempprog="/usr/bin/mktemp"
-pwdmkdbprog="pwd_mkdb"
+pwdmkdbprog="/usr/sbin/pwd_mkdb"
 rmprog="/bin/rm"
 
 progname=deluser
